@@ -36,7 +36,7 @@ def PooledTrainer(base=_NNTrainer, dataset_dir='test', log_dir='net_logs',
             self.log_dir = log_dir
             self.inputspecs = self._parse_inputspec(dataset_dir + _os.sep + kw.get('inputspec_file', 'inputspec.json'))
 
-            cache = {**self.inputspecs[0], 'folds': self._init_folds()}
+            cache = {**self.inputspecs[list(self.inputspecs.keys())[0]], 'folds': self._init_folds()}
             cache['seed'] = _conf.current_seed
             cache.update(**kwargs)
             super().__init__(cache=cache, input={}, state={'clientId': 'LocalMachine'}, **kw)
@@ -53,18 +53,18 @@ def PooledTrainer(base=_NNTrainer, dataset_dir='test', log_dir='net_logs',
                 spec = {}
                 for k, v in isp.items():
                     spec[k] = v['value']
-                inputspec[site] = spec
+                inputspec[f'local{site}'] = spec
             return inputspec
 
         def _load_dataset(self, dataset_cls, split_key):
-            dataset = dataset_cls(mode='train', limit=self.cache.get('load_limit', _conf.max_size))
+            dataset = dataset_cls(mode=split_key, limit=self.cache.get('load_limit', _conf.max_size))
             for site, fold in self.cache['folds'].items():
                 split = fold[self.cache['fold_ix']]
                 path = self.base_directory(site) + _os.sep + self.inputspecs[site]['split_dir']
                 split = _json.loads(open(path + _os.sep + split).read())
                 dataset.add(files=split[split_key],
                             cache={'args': self.inputspecs[site]},
-                            state={'clientId': site, "baseDirectory": self.base_directory(site)})
+                            state={'clientId': f"{site}", "baseDirectory": self.base_directory(site)})
             return dataset
 
         def _save_if_better(self, epoch, val_metrics):
@@ -79,7 +79,7 @@ def PooledTrainer(base=_NNTrainer, dataset_dir='test', log_dir='net_logs',
             return {}
 
         def base_directory(self, site):
-            return f"{self.dataset_dir}/input/local{site}/simulatorRun"
+            return f"{self.dataset_dir}/input/{site}/simulatorRun"
 
         def run(self, dataset_cls, only_sites: list = None, only_folds: list = None):
             global_avg, global_metrics = self.new_averages(), self.new_metrics()
@@ -105,8 +105,9 @@ def PooledTrainer(base=_NNTrainer, dataset_dir='test', log_dir='net_logs',
 
                 if self.cache['mode'] == 'train' or self.cache.get('pretrained_path') is None:
                     self.load_checkpoint(self.cache['log_dir'] + _os.sep + _conf.weights_file)
-                test_datasets = self._load_dataset(dataset_cls, 'test')
-                test_averages, test_metrics = self.evaluation(mode='test', dataset_list=[test_datasets], save_pred=True)
+                test_dataset_list = self._get_test_dataset_list(dataset_cls)
+                test_averages, test_metrics = self.evaluation(mode='test', dataset_list=test_dataset_list,
+                                                              save_pred=True)
 
                 global_avg.accumulate(test_averages), global_metrics.accumulate(test_metrics)
                 self.cache[Key.TEST_METRICS] = [[*test_averages.get(), *test_metrics.get()]]
@@ -133,5 +134,4 @@ def PooledTrainer(base=_NNTrainer, dataset_dir='test', log_dir='net_logs',
                          load_limit=load_limit,
                          pretrained_path=pretrained_path,
                          patience=patience if patience else epochs,
-                         num_workers=num_workers
-                         , **kw)
+                         num_workers=num_workers, **kw)
